==> connector-client-1.0.0-20230323.092234-1-sources.jar: com/daas/nros/connector/model/vo/GiftCardRequestVO.java <==
package com.daas.nros.connector.model.vo;

import com.bizvane.connectorservice.entity.base.BaseModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.ToString;

import java.math.BigDecimal;

/**
 * @Author: xiao.shu
 * @Date: 2019/7/1 16:33
 * @Description:
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
@ToString
public class GiftCardRequestVO extends BaseModel {

    @ApiModelProperty(
            value = "卡号",
            name = "cardNo",
            required = false,
            example = ""
    )
    private String cardNo;
    /**
     * 密码
     */
    @ApiModelProperty(
            value = "密码",
            name = "password",
            required = false,
            example = ""
    )
    private String password;

    @ApiModelProperty(
            value = "变更金额",
            name = "updateBalance",
            required = false,
            example = ""
    )
    private BigDecimal updateBalance;

    @ApiModelProperty(
            value = "余额",
            name = "balance",
            required = false,
            example = ""
    )
    private BigDecimal balance;

    @ApiModelProperty(
            value = "消费会员",
            name = "consumer",
            required = false,
            example = ""
    )
    private String consumer;

    @ApiModelProperty(
            value = "订单号",
            name = "orderNo",
            required = false,
            example = ""
    )
    private String orderNo;

    @ApiModelProperty(
            value = "状态：1未激活 2已激活 3已作废",
            name = "status",
            required = false,
            example = ""
    )
    private String status;

    @ApiModelProperty(
            value = "有效期",
            name = "validityTime",
            required = false,
            example = ""
    )
    private String validityTime;

    @ApiModelProperty(
            value = "1.新增 2.编辑",
            name = "type",
            required = false,
            example = ""
    )
    private String type;

    @ApiModelProperty(
            value = "创建日期",
            name = "createdDate",
            required = false,
            example = ""
    )
    private String createdDate;

    @ApiModelProperty(
            value = "创建人",
            name = "creater",
            required = false,
            example = ""
    )
    private String creater;

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public BigDecimal getUpdateBalance() {
        return updateBalance;
    }

    public void setUpdateBalance(BigDecimal updateBalance) {
        this.updateBalance = updateBalance;
    }

    public BigDecimal getBalance() {
        return balance;
    }

    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }

    public String getConsumer() {
        return consumer;
    }

    public void setConsumer(String consumer) {
        this.consumer = consumer;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getValidityTime() {
        return validityTime;
    }

    public void setValidityTime(String validityTime) {
        this.validityTime = validityTime;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getCreatedDate() {
        return createdDate;
    }

    public void setCreatedDate(String createdDate) {
        this.createdDate = createdDate;
    }

    public String getCreater() {
        return creater;
    }

    public void setCreater(String creater) {
        this.creater = creater;
    }
}

==> connector-client-1.0.0-20230324.072421-3-sources.jar: com/daas/nros/connector/model/vo/GiftCardRequestVO.java <==
package com.daas.nros.connector.model.vo;


import com.daas.nros.connector.model.base.BaseModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.ToString;

import java.math.BigDecimal;

/**
 * @Author: xiao.shu
 * @Date: 2019/7/1 16:33
 * @Description:
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
@ToString
public class GiftCardRequestVO extends BaseModel {

    @ApiModelProperty(
            value = "卡号",
            name = "cardNo",
            required = false,
            example = ""
    )
    private String cardNo;
    /**
     * 密码
     */
    @ApiModelProperty(
            value = "密码",
            name = "password",
            required = false,
            example = ""
    )
    private String password;

    @ApiModelProperty(
            value = "变更金额",
            name = "updateBalance",
            required = false,
            example = ""
    )
    private BigDecimal updateBalance;

    @ApiModelProperty(
            value = "余额",
            name = "balance",
            required = false,
            example = ""
    )
    private BigDecimal balance;

    @ApiModelProperty(
            value = "消费会员",
            name = "consumer",
            required = false,
            example = ""
    )
    private String consumer;

    @ApiModelProperty(
            value = "订单号",
            name = "orderNo",
            required = false,
            example = ""
    )
    private String orderNo;

    @ApiModelProperty(
            value = "状态：1未激活 2已激活 3已作废",
            name = "status",
            required = false,
            example = ""
    )
    private String status;

    @ApiModelProperty(
            value = "有效期",
            name = "validityTime",
            required = false,
            example = ""
    )
    private String validityTime;

    @ApiModelProperty(
            value = "1.新增 2.编辑",
            name = "type",
            required = false,
            example = ""
    )
    private String type;

    @ApiModelProperty(
            value = "创建日期",
            name = "createdDate",
            required = false,
            example = ""
    )
    private String createdDate;

    @ApiModelProperty(
            value = "创建人",
            name = "creater",
            required = false,
            example = ""
    )
    private String creater;

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public BigDecimal getUpdateBalance() {
        return updateBalance;
    }

    public void setUpdateBalance(BigDecimal updateBalance) {
        this.updateBalance = updateBalance;
    }

    public BigDecimal getBalance() {
        return balance;
    }

    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }

    public String getConsumer() {
        return consumer;
    }

    public void setConsumer(String consumer) {
        this.consumer = consumer;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getValidityTime() {
        return validityTime;
    }

    public void setValidityTime(String validityTime) {
        this.validityTime = validityTime;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getCreatedDate() {
        return createdDate;
    }

    public void setCreatedDate(String createdDate) {
        this.createdDate = createdDate;
    }

    public String getCreater() {
        return creater;
    }

    public void setCreater(String creater) {
        this.creater = creater;
    }
}
